- [DATA SOURCE]
    - 463m:
        - Download link:
            - https://astrogeology.usgs.gov/search/map/mars_mgs_mola_dem_463m
        - Hashes:
            - sha256  : 38a4eb0b4452855b8dabfac40a367b458555ab4c01b31235807ad0a53c031f4c
            - xxh3_64 : a0dc027e687f855f
            - md5     : e7920a303f46707d57fe72eab5f6b1aa
    - 200m:
        - Download link:
            - https://astrogeology.usgs.gov/search/map/mars_mgs_mola_mex_hrsc_blended_dem_global_200m
        - Hashes:
            - sha256  : e8bfe4c3b9dee9d5fdb8c4d49798869654e552e7b154712c9e12d6d117464419
            - xxh3_64 : dafb191af5826c66
            - md5     : e98092a06bea74d5ec9a704dcd1fe318
